/*
 * Copyright (c) 1996, 2003 VIA Networking Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *    This product includes software developed by VIA Networking Technologies, Inc.
 * 4. Neither the name of the Company nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY VIA NETWORKING TECHNOLOGIES, INC. AND 
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, 
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL 
 * VIA NETWORKING TECHNOLOGIES, INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *
 * File: if_getb_mii.h
 *
 * Purpose: MII register/macro definition
 *
 * Author: Ryan Fu
 *
 * Date: Jul 22, 2003
 *
 *
 */

#ifndef __IF_GETB_MII_H__
#define __IF_GETB_MII_H__

/*
   Registers in the MII (offset unit is WORD)
 */
#define MII_REG_BMCR        0x00
#define MII_REG_BMSR        0x01
#define MII_REG_PHYID1      0x02
#define MII_REG_PHYID2      0x03
#define MII_REG_ANAR        0x04
#define MII_REG_ANLPAR      0x05
#define MII_REG_G1000CR     0x09
#define MII_REG_G1000SR     0x0A

#define MII_REG_MODCFG      0x10
#define MII_REG_TCSR        0x16
#define MII_REG_LED         0x1B
#define MII_REG_AUXCR       0x1C


#define BMCR_RESET          0x8000
#define BMCR_LBK            0x4000
#define BMCR_SPEED100       0x2000
#define BMCR_AUTO           0x1000
#define BMCR_PD             0x0800
#define BMCR_ISO            0x0400
#define BMCR_REAUTO         0x0200
#define BMCR_FDX            0x0100
#define BMCR_SPEED1G        0x0040


#define BMSR_AUTOCM         0x0020
#define BMSR_LNK            0x0004


#define ANAR_ASMDIR         0x0800
#define ANAR_PAUSE          0x0400
#define ANAR_T4             0x0200
#define ANAR_TXFD           0x0100
#define ANAR_TX             0x0080
#define ANAR_10FD           0x0040
#define ANAR_10             0x0020


#define ANLPAR_ASMDIR       0x0800
#define ANLPAR_PAUSE        0x0400
#define ANLPAR_T4           0x0200
#define ANLPAR_TXFD         0x0100
#define ANLPAR_TX           0x0080
#define ANLPAR_10FD         0x0040
#define ANLPAR_10           0x0020


#define G1000CR_1000FD      0x0200
#define G1000CR_1000        0x0100


#define G1000SR_1000FD      0x0800
#define G1000SR_1000        0x0400

#define TCSR_ECHODIS        0x2000

#define LED_LALBE           0x0004

#define AUXCR_MDPPS         0x0004

#define PHYID_CICADA_CS8201 0x000FC410UL
#define PHYID_VT3216_32BIT  0x000FC610UL
#define PHYID_VT3216_64BIT  0x000FC600UL
#define PHYID_MARVELL_1000  0x01410C50UL
#define PHYID_MARVELL_1000S 0x01410C40UL

#define PHYID_REV_ID_MASK   0x0000000FUL

#define PHYID_GET_PHY_REV_ID(i)     ((i) & PHYID_REV_ID_MASK)
#define PHYID_GET_PHY_ID(i)         ((i) & ~PHYID_REV_ID_MASK)

#define MII_REG_BITS_ON(sc, x, i) do {\
    U16 w;\
    getb_mii_read(sc, i, &w);\
    w |= (x);\
    getb_mii_write(sc, i, w);\
} while (0)

#define MII_REG_BITS_OFF(sc, x, i) do {\
    U16 w;\
    getb_mii_read(sc, i, &w);\
    w &= ~(x);\
    getb_mii_write(sc, i, w);\
} while (0)

#define MII_REG_BITS_IS_ON(sc, x, i) ({\
    U16 w;\
    getb_mii_read(sc, i, &w);\
    ((BOOL) (w & (x)));})

#define MII_GET_PHY_ID(sc) ({\
    U32 id;\
    getb_mii_read(sc, MII_REG_PHYID2, (PU16)&id);\
    getb_mii_read(sc, MII_REG_PHYID1, ((PU16)&id)+1);\
    (id);})



#endif /* __IF_GETB_MII_H__ */
